DigitalLibrary structure
========================

Structure for representing informations about Digital libraries.

.. automodule:: cz_urnnbn_api.api_structures.digital_library
    :members:
    :undoc-members:
    :show-inheritance:
